<?php

if ( ! function_exists( 'add_action' ) )
	exit;

require( 'class-admin-notice.php' );

if( ! class_exists( 'PD_Discord_OAuth_Admin_Menu' ) ){
	
	class PD_Discord_OAuth_Admin_Menu{
		
		/** Rendering menu **/
		public function render_menu(){
			
			$current_tab = isset( $_REQUEST['tab'] ) ? sanitize_text_field( $_REQUEST['tab'] ) : '';
			?>
			<div class="wrap">
				<div>
					<img style="float: left; padding: 8px;" src="<?php echo plugin_dir_url( __FILE__ ); ?>/images/icon_32x32.png">
				</div>
			</div>
		    <div class="wrap">
				<h1><?php esc_html_e( 'SSO OAuth for Discord by path digital', 'pathdigital-discord-oauth' ); ?></h1>
			</div>
			<div id="tab">
				<h2 class="nav-tab-wrapper">
					<a id="tab-configure" class="nav-tab <?php if( $current_tab == 'configure' ) echo 'nav-tab-active'; ?>" href="admin.php?page=pd_discord_oauth_settings&tab=configure"><?php esc_html_e( 'Configure', 'pathdigital-discord-oauth' ); ?></a>
				</h2>
			</div>
			<?php
			if( $current_tab == '' ){
				?>
				
				<script>
					location.href = '<?php echo add_query_arg( array( 'tab' => 'configure' ), htmlentities( $_SERVER['REQUEST_URI'] ) ); ?>';
				</script>
				
				<?php
			}
			?>
			
			<div class="pd-settings-wrap">
				<div class="pd-has-cols">
					<div class="pd-content">
						<?php
						self::render_content( $current_tab );
						?>
					</div>
					<div class="pd-sidebar">
						<div class="pd-box">
							<h3>About path digital</h3>
							<img src="<?php echo plugin_dir_url( __FILE__ ); ?>/images/pathdigital_128x128.png" alt="pathdigital">
							<p>path digital is a digital agency that brings digital products on the path to success.</p>
							<p>With our experience and passion for technology and design, we strive for perfection and uniqueness in every project with the goal of adding value to your product.</p>
							<p>Let’s bring your product on the path to success.</p>
							<a href="https://discord.gg/wtR67uGRsK" class="button button-primary button-large" target="_blank">Join Discord</a>
						</div>
					</div>
				</div>
			</div>
			
			<?php
		}

		/** Rendering the page content **/
		function render_content( $page ){
			
			if ( $page == 'configure' ){
				
				$pages = get_pages( array(
					'sort_order' => 'asc',
					'sort_column' => 'post_title',
					'post_type' => 'page',
					'post_status' => 'publish'
				) );
				$saved_configuration = unserialize( get_option( '_pd_discord_oauth_configuration_settings' ) );
				
				?>
				<div class="pd-box">
					<h3><?php esc_html_e( 'Configure Discord', 'pathdigital-discord-oauth' ); ?> </h3>
					<form name="update_conguration" method="POST" action="admin.php?page=pd_discord_oauth_settings&tab=configure&action=update_configuration">
						<table class="form-table" role="presentation">
							<tr>
								<th scope="row">
									<label for="pd_login_page">Login Page <span class="pd-required">*</span></label>
								</th>
								<td>
									<select name="pd_login_page" id="pd_login_page" class="regular-text" required onchange="pd_update_redirect_url( this )">
										<option value="" disabled<?php echo ( ! isset( $saved_configuration['login_page'] ) || ( isset( $saved_configuration['login_page'] ) && get_post_status( intval( $saved_configuration['login_page'] ) ) !== 'publish' ) ? ' selected' : '' ) ?>>Select...</option>
										<?php
										foreach( $pages as $page ){
											echo '<option value="' . $page->ID . '" data-url="' . get_permalink( $page->ID ) . '"' . ( isset( $saved_configuration['login_page'] ) && intval( $saved_configuration['login_page'] ) === $page->ID ? ' selected' : '' ) . '>' . $page->post_title . '</option>';
										}
										?>
									</select>
									<p class="description" style="font-size: 13px;">Page that shows the login button and is used as the redirect page</p>
								</td>
							</tr>
							<tr>
								<th scope="row">
									<label for="pd_redirect_url">Redirect URL <span class="pd-required">*</span></label>
								</th>
								<td>
									<input name="pd_redirect_url" type="text" id="pd_redirect_url" value="<?php echo esc_url( isset( $saved_configuration['redirect_url'] ) ? $saved_configuration['redirect_url'] : '' ); ?>" class="medium-text" required readonly>
									<button type="button" class="button gray pd-copy-to-clipboard" title="Copy to clipboard" onclick="pd_copy_to_clipboard( this )"></button>
								</td>
							<tr/>
							<tr>
								<th scope="row">
									<label for="pd_client_id">Client ID <span class="pd-required">*</span></label>
								</th>
								<td>
									<input name="pd_client_id" type="text" id="pd_client_id" value="<?php echo esc_attr( isset( $saved_configuration['client_id'] ) ? $saved_configuration['client_id'] : '' ); ?>" class="medium-text" required>
								</td>
							<tr/>
							<tr>
								<th scope="row">
									<label for="pd_client_secret">Client Secret <span class="pd-required">*</span></label>
								</th>
								<td>
									<input name="pd_client_secret" type="password" id="pd_client_secret" value="<?php echo esc_attr( isset( $saved_configuration['client_secret'] ) ? $saved_configuration['client_secret'] : '' ); ?>" class="medium-text" required>
								</td>
							</tr>
							<tr>
								<th scope="row">
									<label for="pd_scope">Scope</label>
								</th>
								<td>
									<input name="pd_scope" type="text" id="pd_scope" value="<?php echo esc_attr( isset( $saved_configuration['scope'] ) ? $saved_configuration['scope'] : 'identify guilds' ); ?>" class="medium-text">
								</td>
							</tr>
							<tr>
								<th scope="row">
									<label for="pd_authorization_url">Base Authorization URL <span class="pd-required">*</span></label>
								</th>
								<td>
									<input name="pd_authorization_url" type="url" id="pd_authorization_url" value="<?php echo esc_url( isset( $saved_configuration['base_authorization_url'] ) ? $saved_configuration['base_authorization_url'] : 'https://discordapp.com/api/oauth2/authorize' ); ?>" class="medium-text" required>
								</td>
							</tr>
							<tr>
								<th scope="row">
									<label for="pd_token_url">Token URL <span class="pd-required">*</span></label>
								</th>
								<td>
									<input name="pd_token_url" type="url" id="pd_token_url" value="<?php echo esc_url( isset( $saved_configuration['token_url'] ) ? $saved_configuration['token_url'] : 'https://discordapp.com/api/oauth2/token' ); ?>" class="medium-text" required>
								</td>
							</tr>
							<tr>
								<th scope="row">
									<label for="pd_user_info_endpoint">User Info Endpoint <span class="pd-required">*</span></label>
								</th>
								<td>
									<input name="pd_user_info_endpoint" type="url" id="pd_user_info_endpoint" value="<?php echo esc_url( isset( $saved_configuration['user_info_endpoint'] ) ? $saved_configuration['user_info_endpoint'] : 'https://discordapp.com/api/users/@me' ); ?>" class="medium-text" required>
								</td>
							</tr>
							<tr>
								<th scope="row">
									<label for="pd_user_guilds_endpoint">User Guilds Endpoint <span class="pd-required">*</span></label>
								</th>
								<td>
									<input name="pd_user_guilds_endpoint" type="url" id="pd_user_guilds_endpoint" value="<?php echo esc_url( isset( $saved_configuration['user_guilds_endpoint'] ) ? $saved_configuration['user_guilds_endpoint'] : 'https://discordapp.com/api/users/@me/guilds' ); ?>" class="medium-text" required>
								</td>
							</tr>
							<tr>
								<th scope="row">
									<label for="pd_servers">Server ID's</label>
								</th>
								<td>
									<textarea name="pd_servers" id="pd_servers" class="medium-text" rows="4"><?php echo esc_textarea( isset( $saved_configuration['server_ids'] ) ? implode( PHP_EOL, $saved_configuration['server_ids'] ) : '' ); ?></textarea>
									<p class="description" style="font-size: 13px;">One server ID per line.	Leave this empty to skip server validation.</p>
								</td>
							</tr>
							<tr>
								<th scope="row">
									&nbsp;
								</th>
								<td>
									<input type="submit" name="pd_submit_update_configuration" value="Save Changes" class="button button-primary button-large">
								</td>
							</tr>
						</table>
						<input type="hidden" name="method" value="pd_update_configuration">
						<?php wp_nonce_field( 'pd_update_configuration_form','pd_update_configuration_form_field' ); ?>
					</form>
					<div class="pd-tip">
						<hr>
						Please refer <a href="https://discord.com/developers/docs/topics/oauth2" target="_blank">https://discord.com/developers/docs/topics/oauth2</a> for more information.
					</div>
				</div>
				<?php
			}
			
		}

	}
	
}
?>