<?php

if ( ! function_exists( 'add_action' ) )
	exit;

require( 'class-admin-menu.php' );

if( ! class_exists( 'PD_Discord_OAuth_Admin' ) ){
	
	class PD_Discord_OAuth_Admin{
		
		private $plugin_path;
		private $plugin_url;
		private $plugin_version;
		
		public function __construct( $plugin_path, $plugin_url, $plugin_version ){
			
			$this->plugin_path = $plugin_path;
			$this->plugin_url = $plugin_url;
			$this->plugin_version = $plugin_version;
			
        }

		/** Registering styles for the admin area **/
		public static function enqueue_styles( $admin_page ){
			
			if( $admin_page != 'toplevel_page_pd_discord_oauth_settings' )
				return;
			
			wp_enqueue_style( 'pathdigital-discord-oauth',
				$this->plugin_url . '/admin/css/style.css', array(),
				$this->plugin_version
			);

		}

		/** Registering scripts for the admin area **/
		public static function enqueue_scripts( $admin_page ){
			
			if( $admin_page != 'toplevel_page_pd_discord_oauth_settings' )
				return;
			
			wp_enqueue_script( 'pathdigital-discord-oauth',
				$this->plugin_url . '/admin/js/script.js',
				array( 'jquery' ),
				$this->plugin_version,
				true
			);
			
			wp_localize_script( 'pathdigital-discord-auth',
				'pathdigital_discord_oauth_ajax', array( 'ajax_url' => admin_url( 'admin-ajax.php' ), 'plugin_url' => $this->plugin_url )
			);
			
		}
		
		/** Registering admin menu **/
		public static function admin_menu(){
			
			add_menu_page( 'path digital Discord OAuth Settings', 'Discord OAuth', 'administrator', 'pd_discord_oauth_settings', array( 'PD_Discord_OAuth_Admin_Menu', 'render_menu' ), plugin_dir_url( __FILE__ ) . 'images/icon_16x16.png', 99 );
			
			global $submenu;
			unset( $submenu['pd_discord_auth_settings'][0] );
				
		}
		
		/** Updating settings **/
		public function update_settings(){
			
			if( isset( $_POST['method'] ) && sanitize_text_field( wp_unslash( $_POST['method'] ) ) == 'pd_update_configuration' && isset( $_REQUEST['pd_update_configuration_form_field'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_REQUEST['pd_update_configuration_form_field'] ) ), 'pd_update_configuration_form' ) ){
				
				if( current_user_can( 'administrator' ) ){
					
					$login_page = isset( $_POST['pd_login_page'] ) ? intval( $_POST['pd_login_page'] ) : 0;
					$redirect_url = isset( $_POST['pd_redirect_url'] ) ? esc_url_raw( trim( $_POST['pd_redirect_url'] ) ) : '';
					$client_id =  isset( $_POST['pd_client_id'] ) ? sanitize_text_field( trim( $_POST['pd_client_id'] ) ) : '';
					$client_secret = isset( $_POST['pd_client_secret'] ) ? sanitize_text_field( trim( $_POST['pd_client_secret'] ) ) : '';
					$scope = ( isset( $_POST['pd_scope'] ) && $_POST['pd_scope'] != '' ) ? sanitize_text_field( trim( $_POST['pd_scope'] ) ) : 'identify guilds';
					$base_authorization_url = isset( $_POST['pd_authorization_url'] ) ? esc_url_raw( trim( $_POST['pd_authorization_url'] ) ) : '';
					$token_url = isset( $_POST['pd_token_url'] ) ? esc_url_raw( trim( $_POST['pd_token_url'] ) ) : '';
					$user_info_endpoint = isset( $_POST['pd_user_info_endpoint'] ) ? esc_url_raw( trim( $_POST['pd_user_info_endpoint'] ) ) : '';
					$user_guilds_endpoint = isset( $_POST['pd_user_guilds_endpoint'] ) ? esc_url_raw( trim( $_POST['pd_user_guilds_endpoint'] ) ) : '';
					$server_ids = isset( $_POST['pd_servers'] ) ? sanitize_textarea_field( trim( $_POST['pd_servers'] ) ) : '';
					
					/** Chaking all the inputs for empty values **/
					if( empty( $login_page ) || empty( $redirect_url ) || empty( $client_id ) || empty( $client_secret ) || empty( $base_authorization_url ) || empty( $token_url ) || empty( $user_info_endpoint ) || empty( $user_guilds_endpoint ) ){
						
						update_option( '_pd_discord_oauth_notice', 'Please fill in all the required fields.' );
						pd_discord_oauth_show_admin_notice( 'error' );
						return;
						
					}
					
					/** Client ID should be integer  **/
					if( filter_var( $client_id, FILTER_VALIDATE_INT ) === FALSE ) {
						
						update_option( '_pd_discord_oauth_notice', 'Please enter a valid Client ID.' );
						pd_discord_oauth_show_admin_notice( 'error' );
						return;
						
					}
					
					/** Scope should be alphabetic */
					if( ctype_alpha( str_replace( ' ', '', $scope ) ) === FALSE ) {
						
						update_option( '_pd_discord_oauth_notice', 'Please enter a valid scope.' );
						pd_discord_oauth_show_admin_notice( 'error' );
						return;
						
					}
					
					$server_ids = str_replace( ',', PHP_EOL, $server_ids );
					$server_ids = explode( PHP_EOL, $server_ids );
					$server_ids_array = array_filter( array_map( 'trim', $server_ids ) );
					
					foreach( $server_ids_array as $server_id ){
						
						/** Server ID should be integer  **/
						if( filter_var( $server_id, FILTER_VALIDATE_INT ) === FALSE ) {
							
							update_option( '_pd_discord_oauth_notice', 'Please enter a valid server ID\'s.' );
							pd_discord_oauth_show_admin_notice( 'error' );
							return;
							
						}
						
					}
					
					$settings = array(
						'login_page' => $login_page,
						'redirect_url' => $redirect_url,
						'client_id' => $client_id,
						'client_secret' => $client_secret,
						'scope' => $scope,
						'base_authorization_url' => $base_authorization_url,
						'token_url' => $token_url,
						'user_info_endpoint' => $user_info_endpoint,
						'user_guilds_endpoint' => $user_guilds_endpoint,
						'server_ids' => $server_ids_array
					);
					
					update_option( '_pd_discord_oauth_configuration_settings', serialize( $settings ) );
					update_option( '_pd_discord_oauth_notice', 'Settings saved successfully.' );
					pd_discord_oauth_show_admin_notice( 'success' );
					
				}
				
			}
			
		}
		
	}

}

?>