<?php

if ( ! function_exists( 'add_action' ) )
	exit;

if( ! class_exists( 'PD_Discord_OAuth_Dicord' ) ){
	
	class PD_Discord_OAuth_Dicord{
		
		protected static $id;
		protected static $username;
		protected static $avatar;
		protected static $discriminator;
		protected static $authenticated;
		protected static $user_in_server;
		
		public function __construct(){
			
			self::$id = NULL;
			self::$username = NULL;
			self::$avatar = NULL;
			self::$discriminator = NULL;
			self::$authenticated = FALSE;
			self::$user_in_server = FALSE;
			
        }
		
		/** Authenticate user with discord **/
		public function authenticate() {
			
			$configuration_settings = unserialize( get_option( '_pd_discord_oauth_configuration_settings' ) );
			
			if( ( isset( $_GET['code'] ) && ! empty( $_GET['code'] ) ) && ( isset( $_GET['state'] ) && sanitize_text_field( $_GET['state'] ) === sanitize_text_field( $_SESSION['state'] ) ) ){
				
				/** Exchange the auth code for a token **/
				$api_response = self::api_request( $configuration_settings['token_url'], $configuration_settings['client_id'], $configuration_settings['client_secret'], array (
					'grant_type' => 'authorization_code',
					'client_id' => $configuration_settings['client_id'],
					'client_secret' => $configuration_settings['client_secret'],
					'redirect_uri' => get_permalink( $configuration_settings['login_page'] ),
					'code' => sanitize_text_field( $_GET['code'] )
				), TRUE );
				
				if( ! isset( $api_response->errors ) && $api_response['response']['code'] === 200 ){
					
					$body = json_decode( $api_response['body'], true );
					
					if( isset( $body['access_token'] ) ) {
						
						if ( ! isset( $_SESSION ) ) {
							
							session_name( md5( get_site_url() ) );
							session_start();
							
						}
						
						$_SESSION['pd_discord_oauth_at'] = $body['access_token'];
						
						$servers = $configuration_settings['server_ids'];
						
						/** If the user in server **/
						if( self::user_in_server( $servers ) )
							self::$authenticated = TRUE;			
						
					}else{
						
						self::throw_error( 'Invalid access token' );
						
					}
					
				}else{
					
					self::throw_error( 'Invalid response from the discord' );
					
				}
				
			}
			
		}
		
		/** Login **/
		public static function login( $servers ){
			
			if ( ! isset( $_SESSION ) )  {
				
				session_name( md5( get_site_url() ) );
				session_start();
				
			}
			
			if( isset( $_GET['pd_discord_oauth_logout'] ) && $_GET['pd_discord_oauth_logout'] )
				unset( $_SESSION['pd_discord_oauth_at'] );

			if ( isset( $_SESSION['pd_discord_oauth_at'] ) ) {
				
				if( self::user_in_server( $servers ) )
					self::$authenticated = TRUE;
				
			}else{
				
				self::authenticate();
				
			}
			
		}
		
		/** Get user guilds **/
		public function get_user_guilds(){
			
			$configuration_settings = unserialize( get_option( '_pd_discord_oauth_configuration_settings' ) );
			$api_response = self::api_request( $configuration_settings['user_guilds_endpoint'] );
			$guilds = ( ! isset( $api_response->errors ) && $api_response['response']['code'] === 200 ) ? json_decode( $api_response['body'], true ) : array();
			
			return $guilds;
			
		}
		
		/** Check if the user in correct server **/
		public function user_in_server( $servers ) {
			
			if( empty( $servers ) )
				return TRUE;
			
			$guilds = self::get_user_guilds();
			
			foreach ( $guilds as $guild ) {
				
				if( isset( $guild['id'] ) ) {
					
					if( in_array( $guild['id'], $servers ) ) {
						
						self::$user_in_server = TRUE;
						
						return TRUE;
						
					}
					
				}
			
			}
			
			self::throw_error( 'Sorry! you are not in selected server(s)' );
			
		}
		
		/** Call the API **/
		private function api_request( $endpoint, $client_id = NULL, $client_secret = NULL, $body = NULL, $post = FALSE ){
			
			$headers = array(
				'Accept'  => 'application/json',
				'charset'       => 'UTF - 8',
				'Authorization' => 'Basic ' . base64_encode( $client_id . ':' . $client_secret ),
				'Content-Type' => 'application/x-www-form-urlencoded',
            );
			
			if ( ! isset( $_SESSION ) ) {
				
				session_name( md5( get_site_url() ) );
				session_start();
				
			}
			
			if( isset( $_SESSION['pd_discord_oauth_at'] ) && ! $post ) {
						
				$headers['Authorization'] = 'Bearer ' . sanitize_text_field( $_SESSION['pd_discord_oauth_at'] );
				
				$response = wp_remote_get( $endpoint, array(
					'method' => 'GET',
					'timeout' => 45,
					'redirection' => 5,
					'httpversion' => '1.0',
					'blocking' => true,
					'headers' => $headers,
					'cookies' => array(),
					'sslverify' => false
				) );
				
			}else{
				
				$response = wp_remote_post( $endpoint, array(
					'method' => 'POST',
					'timeout' => 45,
					'redirection' => 5,
					'httpversion' => '1.0',
					'blocking' => true,
					'headers' => $headers,
					'body' => $body,
					'cookies' => array(),
					'sslverify' => false
				) );
				
			}
			
			return $response;
			
		}
		
		/** Throw an error **/
		private static function throw_error( $message ){
			
			$configuration_settings = unserialize( get_option( '_pd_discord_oauth_configuration_settings' ) );
			$email_text = get_option( 'admin_email' ) != '' ? 'Please contact <a href="mailto:' . get_option( 'admin_email' ) . '">' . get_option( 'admin_email' ) . '</a> or ' : '';
			$re_login_text = '<a href="' . get_permalink( $configuration_settings['login_page'] ) . ( get_option( 'permalink_structure' ) != '' ? '?' : '&' ) . 'pd_discord_oauth_logout=1&method=re_try">Go back to login page</a>.';
			
			$error_message = '<div style="font-size: 1.25em; font-family: sans-serif;">';
				$error_message .= $message . '<br />' . $email_text . $re_login_text;
			$error_message .= '</div>';
			
			exit( $error_message );
			
		}
		
		/** Is authenticated **/
		public static function is_authenticated(){
			
			return self::$authenticated;
			
		}
		
		/** Is user in server **/
		private static function is_user_in_server(){
			
			return self::$user_in_server;
			
		}
		
	}

}

?>