<?php
/**
 * Plugin Name: SSO OAuth for Discord by path digital
 * Description: Discord oAuth for your Website. Hide your website content with Discord SSO and make it only available for your server members.  
 * Version: 1.0.1
 * Author: path digital
 * Author URI: https://pathdigital.de/
 * Tags: Discord, SSO, Login, OAuth, Discord Login, Social Login
 * License: GPLv2 or later
*/

if ( ! function_exists( 'add_action' ) )
	exit;

require( 'constants.php' );
require( 'admin/class-admin.php' );
require( 'includes/class-discord.php' );

if( ! class_exists( 'PD_Discord_OAuth' ) ){
	
	class PD_Discord_OAuth{
		
		private static $plugin_path;
		private static $plugin_url;
		private static $plugin_version;
		
		/** On plugin activation **/
		public function activation(){
			
			if( ! get_option( '_pd_discord_oauth_configuration_settings' ) )
				add_option( '_pd_discord_oauth_configuration_settings', serialize( array( ) ) );
				
			
		}
		
		/** Running the plugin **/
		public function run(){
			
			self::$plugin_path = PD_DISCORD_OAUTH_PLUGIN_DIR_PATH;
			self::$plugin_url = PD_DISCORD_OAUTH_PLUGIN_URL;
			self::$plugin_version = PD_DISCORD_OAUTH_PLUGIN_VERSION;
			
			self::render_admin();
			self::render();
			
        }
		
		/** Rendering admin area **/
		private function render_admin(){
			
			$plugin_admin = new PD_Discord_OAuth_Admin( self::$plugin_path, self::$plugin_url, self::$plugin_version );
			add_action( 'admin_menu', array( $plugin_admin, 'admin_menu' ) );
			add_action( 'admin_enqueue_scripts', array( $plugin_admin, 'enqueue_styles' ) );
			add_action( 'admin_enqueue_scripts', array( $plugin_admin, 'enqueue_scripts' ) );
			add_action( 'admin_init', array( $plugin_admin, 'update_settings' ) );
			
		}
		
		/** Rendering front-end **/
		private function render(){
			
			add_action( 'wp_enqueue_scripts', array( __CLASS__, 'enqueue_styles' ) );
			add_action( 'wp_enqueue_scripts', array( __CLASS__, 'enqueue_scripts' ) );
			add_action( 'wp', array( __CLASS__, 'redirect' ) );
			add_filter( 'the_content', array( __CLASS__, 'login_button' ) );
			
		}
		
		/** Login button **/
		public static function login_button( $content ){
			
			$configuration_settings = unserialize( get_option( '_pd_discord_oauth_configuration_settings' ) );
			
			if( ! isset( $configuration_settings['login_page'] ) )
				return $content;
			
			if( ! is_page( $configuration_settings['login_page'] ) )
				return $content;
			
			if ( ! isset( $_SESSION ) && ! is_user_logged_in() ) {
				
				session_name( md5( get_site_url() ) );
				session_start();
				
			}
			
			$state = bin2hex( openssl_random_pseudo_bytes( 12 ) );
			
			$params = array(
				'client_id' => $configuration_settings['client_id'],
				'redirect_uri' => get_permalink( $configuration_settings['login_page'] ),
				'response_type' => 'code',
				'scope' => $configuration_settings['scope'],
				'state' => $state
			);
			
			/** Saving the sate in session for later validation **/
			$_SESSION['state'] = $state;
			
			$html = '<div class="pd-login-button-wrap">';
				$html .= '<div class="wp-block-button">';
					$html .= '<a href="' . ( ! is_user_logged_in() ? esc_url( $configuration_settings['base_authorization_url'] ) . '?' . http_build_query( $params ) : '#' ) . '" class="wp-block-button__link button">' . __( 'Login with Discord', 'pathdigital-discord-oauth' ) . '</a>';
				$html .= '</div>';
			$html .= '</div>';
			
			if( is_user_logged_in() )
				$html .= '<p><center><font color="red" size="2">Please log out to check the button functionality.</font></center></p>';
			
			return $content . $html;
			
		}
		
		/** Registering styles for the front end **/
		public static function enqueue_styles(){
			
			wp_enqueue_style( 'pathdigital-discord-oauth',
				self::$plugin_url . '/css/style.css', array(),
				self::$plugin_version
			);
			
		}
		
		/** Registering scripts for the front end **/
		public static function enqueue_scripts(){
			
			wp_enqueue_script( 'pathdigital-discord-oauth',
				self::$plugin_url . '/js/script.js',
				array( 'jquery' ),
				self::$plugin_version,
				true
			);
			
			wp_localize_script( 'pathdigital-discord-auth',
				'pathdigital_discord_oauth_ajax', array( 'ajax_url' => admin_url( 'admin-ajax.php' ), 'plugin_url' => self::$plugin_url )
			);
			
		}
		
		/** Redirecting users **/
		public static function redirect(){
			
			if( is_user_logged_in() )
				return;
			
			$configuration_settings = unserialize( get_option( '_pd_discord_oauth_configuration_settings' ) );
			
			if( ! isset( $configuration_settings['login_page'] ) )
				return;
			
			$discord = new PD_Discord_OAuth_Dicord();
			
			$servers = $configuration_settings['server_ids'];

			$discord->login( $servers );
			$is_authenticated = $discord->is_authenticated();
			
			if( $is_authenticated ){
				
				if( is_page( $configuration_settings['login_page'] ) ){
					
					sleep( 1 );
					wp_redirect( get_site_url() );
					
				}		
				
			}else{
				
				if( ! is_page( $configuration_settings['login_page'] ) ){
					
					wp_redirect( get_permalink( $configuration_settings['login_page'] ) );
					
				}
				
			}
			
		}
		
		
	}
}

register_activation_hook( __FILE__, array( 'PD_Discord_OAuth', 'activation' ) );
add_action( 'plugins_loaded', array( 'PD_Discord_OAuth', 'run' ) );
?>